<?php

namespace RUMCWV;

if (!defined('ABSPATH')) {
	die('Let\'s not do this');
}


/**
 * Install The Core Web Vitals plugin class
 * - install hook
 * - check for updates
 * - add cron job
 */
class RUMCWV_Install
{
	public static function init()
	{

		// install hooks
		register_activation_hook(__FILE__, 'RUMCWV\RUMCWV_Install::install');
		register_uninstall_hook(__FILE__, 'RUMCWV\RUMCWV_Install::uninstall');

		// check for db updates / install
		RUMCWV_Install::install();

		// add cron job
		add_action('hourly_cron', 'RUMCWV\RUMCWV_Install::hourly_cron');
	}

	/**
	 * UnInstall RUM CWV
	 * - remves tables
	 * - add cron
	 * @return void
	 */
	public static function uninstall()
	{
		// if uninstall.php is not called by WordPress, die
		if (!defined('WP_UNINSTALL_PLUGIN')) {
			die;
		}

		delete_option('rum_cwv_options');
		delete_site_option('rum_cwv_options');

		wp_clear_scheduled_hook('hourly_cron');
		RUMCWV_RumDB::dropTable();
	}




	/**
	 * InstallRUM CWV
	 * - create tables
	 * - add cron
	 * @return void
	 */
	public static function install()
	{
		$rum_cwv_db_version = get_option("rum_cwv_db_version");

		if ($rum_cwv_db_version != RUM_CWV_VERSION) {

			// update database version
			update_option("rum_cwv_db_version", RUM_CWV_VERSION);

			// tables
			RUMCWV_RumDB::createTable();


			// cron
			wp_clear_scheduled_hook('hourly_cron');
			if (!wp_next_scheduled('hourly_cron')) {
				wp_schedule_event(time(), 'hourly', 'hourly_cron');
			}
		}
	}



	/**
	 * Hourly CRON
	 * - move rum data from tmp to main table
	 * @return void
	 */
	public static function hourly_cron()
	{
		// flatten rum data
		RUMCWV_RumDB::tmp_to_main();

		//precache rum data
		RUMCWV_Rum::precache();

		// delete older rum data
		RUMCWV_RumDB::deleteOlder();
	}
}